@@ -3,8 +3,8 @@
 #'
 #' @description Returns the names of the predictor variables for the
 #'    different parts of a model (like fixed or random effects, zero-inflated
-#'    component, ...). Unlike \code{\link{find_parameters}}, the names from
-#'    \code{find_predictors()} match the original variable names from the data
+#'    component, ...). Unlike [find_parameters()], the names from
+#'    `find_predictors()` match the original variable names from the data
 #'    that was used to fit the model.
 #'
 #' @param x A fitted model.
@@ -15,25 +15,25 @@
 #'   term or the instrumental variables be returned? Applies to models
 #'   with zero-inflated and/or dispersion formula, or to models with instrumental
 #'   variable (so called fixed-effects regressions). May be abbreviated. Note that the
-#'   \emph{conditional} component is also called \emph{count} or \emph{mean}
+#'   *conditional* component is also called *count* or *mean*
 #'   component, depending on the model.
-#' @param flatten Logical, if \code{TRUE}, the values are returned
+#' @param flatten Logical, if `TRUE`, the values are returned
 #'    as character vector, not as list. Duplicated values are removed.
 #' @param verbose Toggle warnings.
 #' @param ... Currently not used.
 #'
 #' @return A list of character vectors that represent the name(s) of the
 #'    predictor variables. Depending on the combination of the arguments
-#'    \code{effects} and \code{component}, the returned list has following
+#'    `effects` and `component`, the returned list has following
 #'    elements:
 #'    \itemize{
-#'      \item \code{conditional}, the "fixed effects" terms from the model
-#'      \item \code{random}, the "random effects" terms from the model
-#'      \item \code{zero_inflated}, the "fixed effects" terms from the zero-inflation component of the model
-#'      \item \code{zero_inflated_random}, the "random effects" terms from the zero-inflation component of the model
-#'      \item \code{dispersion}, the dispersion terms
-#'      \item \code{instruments}, for fixed-effects regressions like \code{ivreg}, \code{felm} or \code{plm}, the instrumental variables
-#'      \item \code{correlation}, for models with correlation-component like \code{gls}, the variables used to describe the correlation structure
+#'      \item `conditional`, the "fixed effects" terms from the model
+#'      \item `random`, the "random effects" terms from the model
+#'      \item `zero_inflated`, the "fixed effects" terms from the zero-inflation component of the model
+#'      \item `zero_inflated_random`, the "random effects" terms from the zero-inflation component of the model
+#'      \item `dispersion`, the dispersion terms
+#'      \item `instruments`, for fixed-effects regressions like `ivreg`, `felm` or `plm`, the instrumental variables
+#'      \item `correlation`, for models with correlation-component like `gls`, the variables used to describe the correlation structure
 #'    }
 #'
 #' @examples
@@ -41,15 +41,11 @@
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' find_predictors(m)
 #' @export
-find_predictors <- function(x,
-                            effects = c("fixed", "random", "all"),
-                            component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "correlation", "smooth_terms"),
-                            flatten = FALSE,
-                            verbose = TRUE,
-                            ...) {
+find_predictors <- function(x, ...) {
   UseMethod("find_predictors")
 }
 
+#' @rdname find_predictors
 #' @export
 find_predictors.default <- function(x,
                                     effects = c("fixed", "random", "all"),
@@ -103,6 +99,8 @@ find_predictors.default <- function(x,
   }
 }
 
+
+
 #' @export
 find_predictors.afex_aov <- function(x,
                                      effects = c("fixed", "random", "all"),
@@ -189,5 +187,15 @@ find_predictors.afex_aov <- function(x,
     f[["zero_inflated_random"]] <- .get_group_factor(x, f[["zero_inflated_random"]])
   }
 
+  # same for sigma-random effects
+  if (.obj_has_name(f, "sigma_random")) {
+    f[["sigma_random"]] <- .get_group_factor(x, f[["sigma_random"]])
+  }
+
+  # same for beta-random effects
+  if (.obj_has_name(f, "beta_random")) {
+    f[["beta_random"]] <- .get_group_factor(x, f[["beta_random"]])
+  }
+
   f
 }
