@@ -66,6 +66,12 @@ if (require("testthat") &&
     expect_null(get_weights(m2))
   })
 
+  test_that("get_deviance + logLik", {
+    expect_equal(get_deviance(m2), 1697.449311, tolerance = 1e-3)
+    expect_equal(get_loglikelihood(m2), logLik(m2), tolerance = 1e-3, ignore_attr = TRUE)
+    expect_equal(get_df(m2, type = "model"), 4)
+  })
+
   test_that("model_info", {
     expect_true(model_info(m1)$is_zero_inflated)
     expect_false(model_info(m2)$is_zero_inflated)
@@ -195,10 +201,10 @@ if (require("testthat") &&
       colnames(get_data(m2, effects = "all")),
       c("count", "child", "camper", "persons")
     )
-    expect_equal(colnames(get_data(m2, effects = "random")), "persons")
+    expect_equal(colnames(get_data(m2, effects = "random", verbose = FALSE)), "persons")
     get_data(m3)
-    expect_equal(colnames(get_data(m6)), "count")
-    expect_null(get_data(m6, effects = "random"))
+    expect_equal(colnames(get_data(m6, verbose = FALSE)), "count")
+    expect_null(get_data(m6, effects = "random", verbose = FALSE))
   })
 
   test_that("find_predictors", {
@@ -530,7 +536,7 @@ if (require("testthat") &&
       colnames(get_predictors(m4)),
       c("child", "camper", "livebait", "xb")
     )
-    expect_null(get_predictors(m6))
+    expect_null(get_predictors(m6, verbose = FALSE))
   })
 
   test_that("get_random", {
@@ -582,7 +588,7 @@ if (require("testthat") &&
       m4,
       component = "disp", effects = "fixed"
     )), c("count", "xb"))
-    expect_null(get_data(m4, component = "disp", effects = "random"))
+    expect_null(get_data(m4, component = "disp", effects = "random", verbose = FALSE))
   })
 
   test_that("find_paramaters", {
